#
# spec file for package maven-reporting-exec
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-reporting-exec
Version:        2.0.0
Release:        1.2
Summary:        Classes to manage report plugin executions with Maven 3
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/maven-reporting-exec
Source0:        %{name}-%{version}.tar.xz
Source1:        http://www.apache.org/licenses/LICENSE-2.0.txt
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(org.apache.maven.doxia:doxia-sink-api)
BuildRequires:  mvn(org.apache.maven.plugins:maven-invoker-plugin)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-api)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-api)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-util)
BuildRequires:  mvn(org.apache.maven.shared:maven-shared-components:pom:)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-classworlds)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus-xml)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildArch:      noarch

%description
Classes to manage and configure report plugin executions with Maven 3.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
The API documentation of %{name}.

%prep
%setup -q
cp %{SOURCE1} LICENSE.txt

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Tue Oct 15 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.0
  * Bug
    + MSHARED-1298: Missing site report should be detected
  * Improvement
    + MSHARED-1236: Supply execution id of caller (Maven Site
    Plugin) to MavenReportExecutorRequest
    + MSHARED-1329: Add field to MavenReportExecution whether
    it is user-defined or autodetected
  * Task
    + MSHARED-1060: Upgrade to Java 8
    + MSHARED-1061: Replace Plexus Logger with SLF4J
    + MSHARED-1064: Reintroduce org.codehaus.doxia.sink.Sink
    + MSHARED-1105: Replace Plexus Annotations with JSR 330 and
    upgrade relevant dependencies
    + MSHARED-1193: Remove Maven 2 compat code
    + MSHARED-1207: Deprecate
    MavenReportExecutorRequest#localRepository
    + MSHARED-1387: Clean up dependencies
- Fetch sources using source service
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.6.0
- Build with source and target levels 8
- Removed patch:
  * 0001-Port-to-Eclipse-Aether-and-Eclipse-Sisu.patch
    + integrated in this version
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Mon Jun  3 2019 Jan Engelhardt <jengelh@inai.de>
- Trim description repetition of itself.
* Sun May  5 2019 Jan Engelhardt <jengelh@inai.de>
- Add Group: field.
* Fri May  3 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-reporting-exec 1.4
